Index: sdk/lib/core/list.dart |
diff --git a/sdk/lib/core/list.dart b/sdk/lib/core/list.dart |
index a9d82c8b00fee62bad6f2d4227c753209f59af7f..a6ae897e7ee4b6e6e08f5871be713d9356e0519c 100644 |
--- a/sdk/lib/core/list.dart |
+++ b/sdk/lib/core/list.dart |
@@ -87,14 +87,14 @@ abstract class List<E> implements Iterable<E>, EfficientLength { |
external factory List.filled(int length, E fill); |
/** |
- * Creates a list and initializes it using the contents of [other]. |
+ * Creates a list containing all of [elements]. |
* |
* The [Iterator] of [other] provides the order of the objects. |
* |
- * This constructor returns a growable list if [growable] is true; |
+ * This constructor returns a growable list when [growable] is true; |
* otherwise, it returns a fixed-length list. |
*/ |
- external factory List.from(Iterable other, { bool growable: true }); |
+ external factory List.from(Iterable elements, { bool growable: true }); |
/** |
* Generates a list of values. |
@@ -87,14 +87,14 @@ abstract class List<E> implements Iterable<E>, EfficientLength { |
* |
- * The [Iterator] of [other] provides the order of the objects. |
+ * The [Iterator] of [elements] provides the order of the elements. |
* |